@@ -14,10 +14,11 @@ from packaging.utils import canonicalize_name
 
 from pipx import constants
 from pipx.colors import bold, red
-from pipx.emojies import hazard, stars
+from pipx.constants import WINDOWS
+from pipx.emojis import hazard, stars
 from pipx.package_specifier import parse_specifier_for_install, valid_pypi_name
 from pipx.pipx_metadata_file import PackageInfo
-from pipx.util import WINDOWS, PipxError, mkdir, pipx_wrap, rmdir
+from pipx.util import PipxError, mkdir, pipx_wrap, rmdir
 from pipx.venv import Venv
 
 logger = logging.getLogger(__name__)
@@ -212,7 +213,6 @@ def get_package_summary(
     return (
         _get_list_output(
             python_version,
-            python_path,
             package_metadata.package_version,
             package,
             new_install,
@@ -251,7 +251,6 @@ def _get_exposed_app_paths_for_package(
 
 def _get_list_output(
     python_version: str,
-    python_path: Path,
     package_version: str,
     package: str,
     new_install: bool,
@@ -267,9 +266,6 @@ def _get_list_output(
         f" {bold(package_version)}{suffix}, {python_version}"
     )
 
-    if not python_path.exists():
-        output.append(f"    associated python path {str(python_path)} does not exist!")
-
     if new_install and exposed_binary_names:
         output.append("  These apps are now globally available")
     for name in exposed_binary_names:
