@@ -1,15 +1,21 @@
 import json
 import logging
+import re
 import time
 from pathlib import Path
 from subprocess import CompletedProcess
-from typing import Dict, Generator, List, Set
+from typing import Dict, Generator, List, NoReturn, Optional, Set
+
+try:
+    from importlib.metadata import Distribution, EntryPoint
+except ImportError:
+    from importlib_metadata import Distribution, EntryPoint  # type: ignore
 
 from packaging.utils import canonicalize_name
 
 from pipx.animate import animate
 from pipx.constants import PIPX_SHARED_PTH, ExitCode
-from pipx.emojies import hazard
+from pipx.emojis import hazard
 from pipx.interpreter import DEFAULT_PYTHON
 from pipx.package_specifier import (
     fix_package_name,
@@ -29,11 +35,21 @@ from pipx.util import (
     rmdir,
     run_subprocess,
     subprocess_post_check,
+    subprocess_post_check_handle_pip_error,
 )
 from pipx.venv_inspect import VenvMetadata, inspect_venv
 
 logger = logging.getLogger(__name__)
 
+_entry_point_value_pattern = re.compile(
+    r"""
+    ^(?P<module>[\w.]+)\s*
+    (:\s*(?P<attr>[\w.]+))?\s*
+    (?P<extras>\[.*\])?\s*$
+    """,
+    re.VERBOSE,
+)
+
 
 class VenvContainer:
     """A collection of venvs managed by pipx."""
@@ -212,9 +228,17 @@ class Venv:
             f"installing {full_package_description(package, package_or_url)}",
             self.do_animation,
         ):
-            cmd = ["install"] + pip_args + [package_or_url]
-            pip_process = self._run_pip(cmd)
-        subprocess_post_check(pip_process, raise_error=False)
+            # do not use -q with `pip install` so subprocess_post_check_pip_errors
+            #   has more information to analyze in case of failure.
+            cmd = (
+                [str(self.python_path), "-m", "pip", "install"]
+                + pip_args
+                + [package_or_url]
+            )
+            # no logging because any errors will be specially logged by
+            #   subprocess_post_check_handle_pip_error()
+            pip_process = run_subprocess(cmd, log_stdout=False, log_stderr=False)
+        subprocess_post_check_handle_pip_error(pip_process)
         if pip_process.returncode:
             raise PipxError(
                 f"Error installing {full_package_description(package, package_or_url)}."
@@ -327,8 +351,43 @@ class Venv:
         pip_list = json.loads(cmd_run.stdout.strip())
         return set([x["name"] for x in pip_list])
 
-    def run_app(self, app: str, app_args: List[str]) -> None:
-        exec_app([str(self.bin_path / app)] + app_args)
+    def _find_entry_point(self, app: str) -> Optional[EntryPoint]:
+        if not self.python_path.exists():
+            return None
+        dists = Distribution.discover(
+            name=self.main_package_name,
+            path=[str(get_site_packages(self.python_path))],
+        )
+        for dist in dists:
+            for ep in dist.entry_points:
+                if ep.group == "pipx.run" and ep.name == app:
+                    return ep
+        return None
+
+    def run_app(self, app: str, filename: str, app_args: List[str]) -> NoReturn:
+        entry_point = self._find_entry_point(app)
+
+        # No [pipx.run] entry point; default to run console script.
+        if entry_point is None:
+            exec_app([str(self.bin_path / filename)] + app_args)
+
+        # Evaluate and execute the entry point.
+        # TODO: After dropping support for Python < 3.9, use
+        # "entry_point.module" and "entry_point.attr" instead.
+        match = _entry_point_value_pattern.match(entry_point.value)
+        assert match is not None, "invalid entry point"
+        module, attr = match.group("module", "attr")
+        code = (
+            f"import sys, {module}\n"
+            f"sys.argv[0] = {entry_point.name!r}\n"
+            f"sys.exit({module}.{attr}())\n"
+        )
+        exec_app([str(self.python_path), "-c", code] + app_args)
+
+    def has_app(self, app: str, filename: str) -> bool:
+        if self._find_entry_point(app) is not None:
+            return True
+        return (self.bin_path / filename).is_file()
 
     def _upgrade_package_no_metadata(self, package: str, pip_args: List[str]) -> None:
         with animate(
